package de.intevation.flys.artifacts.model;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import gnu.trove.TDoubleArrayList;

import org.apache.log4j.Logger;

public class WQ
extends      W
{
    public static final Pattern NUMBERS_PATTERN =
        Pattern.compile("\\D*(\\d++.\\d*)\\D*");

    private static Logger log = Logger.getLogger(WQ.class);

    protected TDoubleArrayList qs;

    public WQ() {
        this("");
    }

    public WQ(String name) {
        super(name);
        qs = new TDoubleArrayList();
    }

    public WQ(int capacity) {
        this(capacity, "");
    }


    public WQ(int capacity, String name) {
        super(capacity, name);
        qs = new TDoubleArrayList(capacity);
    }

    public WQ(double [] qs, double [] ws) {
        this(qs, ws, "");
    }

    public WQ(double [] qs, double [] ws, String name) {
        super(name);
        this.ws = new TDoubleArrayList(ws);
        this.qs = new TDoubleArrayList(qs);
    }


    public Double getRawValue() {
        if (name == null || name.length() == 0) {
            // this should never happen
            return null;
        }

        Matcher m = NUMBERS_PATTERN.matcher(name);

        if (m.matches()) {
            String raw = m.group(1);

            try {
                return Double.valueOf(raw);
            }
            catch (NumberFormatException nfe) {
                // do nothing
            }
        }

        return null;
    }

    public void add(double w, double q) {
        ws.add(w);
        qs.add(q);
    }

    public double getQ(int idx) {
        return qs.getQuick(idx);
    }

    @Override
    public double [] get(int idx) {
        return get(idx, new double [2]);
    }

    @Override
    public double [] get(int idx, double [] dst) {
        dst[0] = ws.getQuick(idx);
        dst[1] = qs.getQuick(idx);
        return dst;
    }

    public double [] getQs() {
        return qs.toNativeArray();
    }

    @Override
    public void removeNaNs() {
        removeNaNs(new TDoubleArrayList [] { ws, qs });
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
